#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Sample demonstrating how to scale out of a position.
    /// </summary>
    [Description("Sample demonstrating how to scale out of a position.")]
    public class SampleScaleOut : Strategy
    {
        #region Variables
        #endregion

        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			/* The following settings configure your strategy to execute only one entry for each uniquely named entry signal.
			This can be configured in the Initalize() method or via the Strategy dialog window when running or backtesting a strategy */
			EntriesPerDirection = 1;
			EntryHandling 		= EntryHandling.UniqueEntries;
			
            CalculateOnBarClose = true;
			
			/* These Set methods will place Profit Target and Trail Stop orders for our entry orders.
			Notice how the Profit Target order is only tied to our order named 'Long 1a'. This is the crucial step in achieving the following behavior. 
			If the price never reaches our Profit Target, both long positions will be closed via our Trail Stop.
			If the price does hit our Profit Target, half of our position will be closed leaving the remainder to be closed by our Trail Stop. */
			SetProfitTarget("Long 1a", CalculationMode.Ticks, 10);
			SetTrailStop(CalculationMode.Ticks, 8);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Entry Condition: When the Low crosses below the lower bollinger band, enter long
			if (CrossBelow(Low, Bollinger(2, 14).Lower, 1))
			{
				// Only allow entries if we have no current positions open
				if (Position.MarketPosition == MarketPosition.Flat)
				{
					/* Enters two long positions.
					We submit two orders to allow us to be able to scale out half of the position at a time in the future.
					With individual entry names we can differentiate between the first half and the second half of our long position.
					This lets us place a Profit Target order only for the first half and Trail Stops for both. */
					EnterLong("Long 1a");
					EnterLong("Long 1b");
				}
			}
        }
		
        #region Properties
        #endregion
    }
}
